@@ -323,7 +323,8 @@ func dataFor(ctx *context.Context, cfg config.Homebrew, cl client.Client, artifa
 		Dependencies:  cfg.Dependencies,
 		Conflicts:     cfg.Conflicts,
 		Plist:         cfg.Plist,
-		PostInstall:   cfg.PostInstall,
+		Service:       split(cfg.Service),
+		PostInstall:   split(cfg.PostInstall),
 		Tests:         split(cfg.Test),
 		CustomRequire: cfg.CustomRequire,
 		CustomBlock:   split(cfg.CustomBlock),
