@@ -103,7 +103,7 @@ func TestFullFormulae(t *testing.T) {
 	data.Dependencies = []config.HomebrewDependency{{Name: "gtk+"}}
 	data.Conflicts = []string{"svn"}
 	data.Plist = "it works"
-	data.PostInstall = `system "touch", "/tmp/foo"`
+	data.PostInstall = []string{`system "touch", "/tmp/foo"`, `system "echo", "done"`}
 	data.CustomBlock = []string{"devel do", `  url "https://github.com/caarlos0/test/releases/download/v0.1.3/test_Darwin_x86_64.tar.gz"`, `  sha256 "1633f61598ab0791e213135923624eb342196b3494909c91899bcd0560f84c68"`, "end"}
 	data.Tests = []string{`system "#{bin}/{{.ProjectName}} -version"`}
 	formulae, err := doBuildFormula(context.New(config.Project{
@@ -274,6 +274,8 @@ func TestFullPipe(t *testing.T) {
 							Plist:        `<xml>whatever</xml>`,
 							Dependencies: []config.HomebrewDependency{{Name: "zsh", Type: "optional"}, {Name: "bash"}},
 							Conflicts:    []string{"gtk+", "qt"},
+							Service:      "run foo/bar\nkeep_alive true",
+							PostInstall:  "system \"echo\"\nsystem \"touch\" \"/tmp/hi\"",
 							Install:      `bin.install "{{ .ProjectName }}"`,
 						},
 					},
