@@ -46,7 +46,7 @@ func (Pipe) Default(ctx *context.Context) error {
 			fpm.ID = "default"
 		}
 		if fpm.Bindir == "" {
-			fpm.Bindir = "/usr/local/bin"
+			fpm.Bindir = "/usr/bin"
 		}
 		if fpm.PackageName == "" {
 			fpm.PackageName = ctx.Config.ProjectName
@@ -319,10 +319,6 @@ func create(ctx *context.Context, fpm config.NFPM, format string, binaries []*ar
 		info.Deb.Signature = nfpm.DebSignature{}
 	}
 
-	if err = nfpm.Validate(info); err != nil {
-		return fmt.Errorf("invalid nfpm config: %w", err)
-	}
-
 	packager, err := nfpm.Get(format)
 	if err != nil {
 		return err
@@ -346,6 +342,7 @@ func create(ctx *context.Context, fpm config.NFPM, format string, binaries []*ar
 		return err
 	}
 	defer w.Close()
+
 	if err := packager.Package(info, w); err != nil {
 		return fmt.Errorf("nfpm failed: %w", err)
 	}
